==> java-interpreter-0.1.2-sources.jar: uk/modl/transforms/LiteralsTransform.java <==
/*
 * MIT License
 *
 * Copyright (c) 2020 NUM Technology Ltd
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
 * to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of
 * the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
 * OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */

package uk.modl.transforms;

import uk.modl.utils.Util;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class LiteralsTransform {

    public static final Pattern literalsPattern = Pattern.compile("(%`.+`)");

    public static String replacellLiteralRefs(final String s) {
        if (s == null) {
            return null;
        }
        final Matcher matcher = literalsPattern.matcher(s);

        // Gather the match groups into a list of references
        String result = s;
        while (matcher.find()) {
            final String match = matcher.group();
            result = result.replace(match, Util.unwrapLiteral(match));
        }
        return result;
    }

}

==> java-interpreter-0.1.22-sources.jar: uk/modl/transforms/LiteralsTransform.java <==
/*
 * MIT License
 *
 * Copyright (c) 2020 NUM Technology Ltd
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and
 * to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of
 * the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
 * OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */

package uk.modl.transforms;

import lombok.val;
import lombok.var;
import uk.modl.utils.Util;

import java.util.regex.Pattern;

public class LiteralsTransform {

    public static final Pattern literalsPattern = Pattern.compile("(%`.+`)");

    public static String replacellLiteralRefs(final String s) {
        if (s == null) {
            return null;
        }
        val matcher = literalsPattern.matcher(s);

        // Gather the match groups into a list of references
        var result = s;
        while (matcher.find()) {
            val match = matcher.group();
            result = result.replace(match, Util.unwrapLiteral(match));
        }
        return result;
    }

}
